DeRatingMode

Enum DeRatingMode 

pub enum DeRatingMode {
    Normal = 0,
    Derating = 1,
}
Wether the APP33772S will adjust the amount of current given to the device based on the de rating temperature

Variants



Normal = 0

Current will not change unless the one of the thresholds is achieved at which point the device will turn off VOUT via the MOS Switch.



Derating = 1

The Device will change the output current based on the DeRating Temperature. Once the DeRating Temperature is reached the device will drop the current bu 50%

Implementations

Source

impl DeRatingMode

pub const fn raw_value(self) -> UInt<u8, 1usize>

Returns the underlying raw value of this bitfield.

pub const fn new_with_raw_value(value: UInt<u8, 1usize>) -> Self

Creates a new instance of this bitfield with the given raw value.