OperatingCurrentSelection

Enum OperatingCurrentSelection 

pub enum OperatingCurrentSelection {
Show 16 variants _1A = 0, _1_25A = 1, _1_5A = 2, _1_75A = 3, _2A = 4, _2_25A = 5, _2_5A = 6, _2_75A = 7, _3A = 8, _3_25A = 9, _3_5A = 10, _3_75A = 11, _4A = 12, _4_25A = 13, _4_5A = 14, Maximum = 15,
}
Represents the different Currents the device will limit itself too. The actual current the device can support is defined by the SourceMaximumCurrent If the maximum current is requested, the device will use the highest available current level. This can be requested using the negotiate maximum power function

Variants



_1A = 0



_1_25A = 1



_1_5A = 2



_1_75A = 3



_2A = 4



_2_25A = 5



_2_5A = 6



_2_75A = 7



_3A = 8



_3_25A = 9



_3_5A = 10



_3_75A = 11



_4A = 12



_4_25A = 13



_4_5A = 14



Maximum = 15

Implementations

Source

impl OperatingCurrentSelection

pub const fn raw_value(self) -> UInt<u8, 4usize>

Returns the underlying raw value of this bitfield.

pub const fn new_with_raw_value(value: UInt<u8, 4usize>) -> Self

Creates a new instance of this bitfield with the given raw value.

Source

impl OperatingCurrentSelection

pub fn current(&self) -> ElectricCurrent

Returns the Operating Current in a useable uom ElectricCurrent. Where 5A is the “Maximum” value