pub enum PowerDataObject {
Show 13 variants
StandardPowerRange1 = 1,
StandardPowerRange2 = 2,
StandardPowerRange3 = 3,
StandardPowerRange4 = 4,
StandardPowerRange5 = 5,
StandardPowerRange6 = 6,
StandardPowerRange7 = 7,
ExtendedPowerRange8 = 8,
ExtendedPowerRange9 = 9,
ExtendedPowerRange10 = 10,
ExtendedPowerRange11 = 11,
ExtendedPowerRange12 = 12,
ExtendedPowerRange13 = 13,
}Expand description
The Power Data Onject (PDO) represents the different power modes that are supported in the USB C Power Delivery Specificaiton for this chip AP33772S. The chip supports
With a Maximum Voltage of 21V
with a Maximum Voltage of 28V
7 Standard Power Ranges are provided along with 6 Extended Power Ranges. These are not gauranteed to be implemented by every charger
The underlying PowerDataObjects linked above provide a method is_detected() which outlines if it can be used
Variants
StandardPowerRange1 = 1
StandardPowerRange2 = 2
StandardPowerRange3 = 3
StandardPowerRange4 = 4
StandardPowerRange5 = 5
StandardPowerRange6 = 6
StandardPowerRange7 = 7
ExtendedPowerRange8 = 8
ExtendedPowerRange9 = 9
ExtendedPowerRange10 = 10
ExtendedPowerRange11 = 11
ExtendedPowerRange12 = 12
ExtendedPowerRange13 = 13
Implementations