PowerType

Enum PowerType 

pub enum PowerType {
    Fixed = 0,
    Adjustable = 1,
}
The different operational modes that the USB C Specification Supports

Variants



Fixed = 0

In this mode, Programmable Power Supply (PPS) is not used and the voltage will at a fixed rate defined by the Power Data Object



Adjustable = 1

In this mode, Programmable Power Supply (PPS) can be used and the voltage can be tweaked dependent on the configuration of the Power Data Object

Implementations

Source

impl PowerType

pub const fn raw_value(self) -> UInt<u8, 1usize>

Returns the underlying raw value of this bitfield.

pub const fn new_with_raw_value(value: UInt<u8, 1usize>) -> Self

Creates a new instance of this bitfield with the given raw value.