SourcePowerRangeDataObject

Enum SourcePowerRangeDataObject 

pub enum SourcePowerRangeDataObject {
    Standard(StandardPowerRangeDataObject),
    Extended(ExtendedPowerRangeDataObject),
}
Represents A wrapper for the underlying Power Range Data Objects The AP33772s supports both Standard and Extended Power Range Data Objects Individual functions are supplied for generic functionality between the two types

Variants

Implementations