pub struct AllSourceDataPowerDataObject {
pub power_data_objects: [SourcePowerRangeDataObject; 13],
}Expand description
Represents all source power data objects for the AP33772S.
Each USB C Power Supply device will have some of these objects.
In the event that it does not the underlying power data objects is_detected methods will be false.
Fields
power_data_objects: [SourcePowerRangeDataObject; 13]Implementations
Sourceimpl AllSourceDataPowerDataObject
impl AllSourceDataPowerDataObject
Sourcepub fn get_power_data_object(
&self,
index: PowerDataObject,
) -> &SourcePowerRangeDataObject
pub fn get_power_data_object( &self, index: PowerDataObject, ) -> &SourcePowerRangeDataObject
Returns a reference to the power data object at the given index.