OperationMode

Struct OperationMode 

pub struct OperationMode { /* private fields */ }
The OperationMode register is defined as the AP33772S’s operation mode.

When ConfigurationChannel::One, the CC2 is connected to the CC line. See ConfigurationChannel for more details.

When DeRatingMode::Normal, the AP33772S works in de-rating (DR) mode. See DeRatingMode for more details.

When power_delivery_source_connected = true, the AP33772S works in Power Delivery mode.

When legacy_source_connected = true, the AP33772S works in Legacy mode (non Power Delivery Modes).

Datasheet Name: OPMODE

Implementations

Source

impl OperationMode

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const DEFAULT: Self

An instance that uses the default value 0x00

pub const fn new() -> Self

👎Deprecated:

Use OperationMode::Default (or OperationMode::DEFAULT in const context) instead

Creates a new instance of this struct using the default value

pub const fn raw_value(&self) -> u8

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u8) -> OperationMode

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialOperationMode

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn legacy_source_connected(&self) -> bool

Leagacy Source Connected

Datasheet Name: LGCYMOD

pub const fn power_delivery_source_connected(&self) -> bool

Power Delivery Source Connected

Datasheet Name: PDMOD

pub const fn derating_mode(&self) -> DeRatingMode

Derating Mode

Datasheet Name: DR

pub const fn configuration_channel(&self) -> ConfigurationChannel

CCFLIP - CC1 or CC2 connected