Status

Struct Status 

pub struct Status { /* private fields */ }
The host MCU, working as an I2C master, can access the status of the AP33772S through the STATUS register. The STATUS register will be reset to 0 after a read operation.

Datasheet Name: STATUS

Implementations

Source

impl Status

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const DEFAULT: Self

An instance that uses the default value 0x00

pub const fn new() -> Self

👎Deprecated:

Use Status::Default (or Status::DEFAULT in const context) instead

Creates a new instance of this struct using the default value

pub const fn raw_value(&self) -> u8

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u8) -> Status

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialStatus

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn started(&self) -> bool

Detect if the System has started. Allow System Configuration Register to be updated within 100ms of connection.

Datasheet Name: STARTED_MSK

pub const fn i2c_ready(&self) -> bool

Ready to receive I2C request/command

Datasheet Name: READY

pub const fn new_power_data_object(&self) -> bool

New source PDO(Power Data Object)s received

Datasheet Name: NEWPDO

pub const fn under_voltage_protection(&self) -> bool

Under Voltage Protection Status

Datasheet Name: UVP

pub const fn over_voltage_protection(&self) -> bool

Over Voltage Protection Status

Datasheet Name: OVP

pub const fn over_current_protection(&self) -> bool

Over Current Protection Status

Datasheet Name: OCP

pub const fn over_temperature_protection(&self) -> bool

Over Temperature Protection Status

Datasheet Name: OTP

Source

impl Status

pub const RESET: Status