RequestError

Enum RequestError 

#[non_exhaustive]
pub enum RequestError { MissingArgument, VoltageOutOfRange, CurrentOutOfRange, }
This Error is specifically an internal error that is used before communication with the device is taken. The eror enum catches incompatible configurations and notifies the user accordingly.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingArgument



VoltageOutOfRange



CurrentOutOfRange