pub enum PowerType {
Fixed = 0,
Adjustable = 1,
}Expand description
The different operational modes that the USB C Specification Supports
Variants
Fixed = 0
In this mode, Programmable Power Supply (PPS) is not used and the voltage will at a fixed rate defined by the Power Data Object
Adjustable = 1
In this mode, Programmable Power Supply (PPS) can be used and the voltage can be tweaked dependent on the configuration of the Power Data Object
Implementations