pub enum SourcePowerRangeDataObject {
Standard(StandardPowerRangeDataObject),
Extended(ExtendedPowerRangeDataObject),
}Expand description
Represents A wrapper for the underlying Power Range Data Objects The AP33772s supports both Standard and Extended Power Range Data Objects Individual functions are supplied for generic functionality between the two types
Variants
Standard(StandardPowerRangeDataObject)
Extended(ExtendedPowerRangeDataObject)
Implementations
Sourceimpl SourcePowerRangeDataObject
impl SourcePowerRangeDataObject
pub fn voltage_resolution(&self) -> u16
pub fn source_power_type(&self) -> PowerType
pub fn is_detected(&self) -> bool
pub fn get_max_voltage(&self) -> Result<ElectricPotential, Ap33772sError>
pub fn get_max_current(&self) -> SourceMaximumCurrent
pub fn get_min_voltage(&self) -> Result<ElectricPotential, Ap33772sError>