pub struct Status { /* private fields */ }Expand description
The host MCU, working as an I2C master, can access the status of the AP33772S through the STATUS register. The STATUS register will be reset to 0 after a read operation.
Datasheet Name: STATUS
Implementations
Sourceimpl Status
impl Status
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new() -> Self
👎Deprecated: Use Status::Default (or Status::DEFAULT in const context) instead
pub const fn new() -> Self
Use Status::Default (or Status::DEFAULT in const context) instead
Creates a new instance of this struct using the default value
Sourcepub const fn new_with_raw_value(value: u8) -> Status
pub const fn new_with_raw_value(value: u8) -> Status
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialStatus
pub const fn builder() -> PartialStatus
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn started(&self) -> bool
pub const fn started(&self) -> bool
Detect if the System has started. Allow System Configuration Register to be updated within 100ms of connection.
Datasheet Name: STARTED_MSK
Sourcepub const fn i2c_ready(&self) -> bool
pub const fn i2c_ready(&self) -> bool
Ready to receive I2C request/command
Datasheet Name: READY
Sourcepub const fn new_power_data_object(&self) -> bool
pub const fn new_power_data_object(&self) -> bool
New source PDO(Power Data Object)s received
Datasheet Name: NEWPDO
Sourcepub const fn under_voltage_protection(&self) -> bool
pub const fn under_voltage_protection(&self) -> bool
Under Voltage Protection Status
Datasheet Name: UVP
Sourcepub const fn over_voltage_protection(&self) -> bool
pub const fn over_voltage_protection(&self) -> bool
Over Voltage Protection Status
Datasheet Name: OVP
Sourcepub const fn over_current_protection(&self) -> bool
pub const fn over_current_protection(&self) -> bool
Over Current Protection Status
Datasheet Name: OCP
Sourcepub const fn over_temperature_protection(&self) -> bool
pub const fn over_temperature_protection(&self) -> bool
Over Temperature Protection Status
Datasheet Name: OTP